@@ -1,6 +1,6 @@
 package Catmandu::Fix::search_sru;
 
-our $VERSION = '0.427';
+our $VERSION = '0.429';
 
 use Moo;
 use namespace::clean;
@@ -12,10 +12,11 @@ with 'Catmandu::Fix::Builder';
 
 has path         => (fix_arg => 1);
 has base         => (fix_arg => 1);
-has recordschema => (fix_opt => 1, default => sub {'oai_dc'});
-has parser       => (fix_opt => 1, default => sub {'simple'});
-has limit        => (fix_opt => 1, default => sub {10});
 has fixes        => (fix_opt => 1);
+has limit        => (fix_opt => 1, default => sub {10});
+has parser       => (fix_opt => 1, default => sub {'simple'});
+has recordschema => (fix_opt => 1, default => sub {'oai_dc'});
+has total        => (fix_opt => 1);
 
 sub _build_fixer {
     my ($self) = @_;
@@ -35,21 +36,16 @@ sub sru_request {
     my $importer = Catmandu->importer(
         'SRU',
         base         => $self->base,
+        limit        => $self->limit,
         parser       => $self->parser,
         query        => $query,
         recordSchema => $self->recordschema,
-        limit        => $self->limit,
+        total        => $self->total,
     );
-    my $records;
     if (my $fixes = $self->fixes) {
-        my $fixer = Catmandu->fixer($fixes);
-        $records = $fixer->fix($importer)->to_array;
-
+        $importer = Catmandu->fixer($fixes)->fix($importer);
     }
-    else {
-        $records = $importer->to_array;
-    }
-    return $records;
+    $importer->to_array;
 }
 
 1;
@@ -64,7 +60,7 @@ Catmandu::Fix::search_sru - use the value as SRU query, and replace it by SRU se
   
  search_sru( <path>, <url> )
   
- search_sru( <path>, <url>, [recordschema:<SCHEMA>], [parser:<PARSER>], [limit:<INTEGER>], [fixes :<STRING|FILE>] )
+ search_sru( <path>, <url>, [recordschema:<SCHEMA>], [parser:<PARSER>], [limit:<INTEGER>], [total:<INTEGER>], [fixes:<STRING|FILE>] )
 
  # From the command line
 
@@ -86,7 +82,7 @@ Base URL of the SRU server.
  
 =head2 recordschema
  
-SRU record schema. Use SRU Explain operation to look up available schemas.
+SRU record schema. Use SRU Explain operation to look up available schema.
  
 Default is 'oai_dc'.
  
@@ -100,13 +96,17 @@ Default is 'simple'.
 
 =head2 limit
  
-Number of records to fetch. This is translated to SRU request parameter maximumRecords.
+Maximum number of records to fetch per request.
 
 Default is 10.
+
+=head2 total
+ 
+Maximum number of records to fetch from a result set.
  
 =head2 fixes
  
- L<Catmandu::Fix> to transform the parsed records of the SRU response.
+L<Catmandu::Fix> to transform the parsed records of the SRU response.
    
 =head1 SEE ALSO
  
